@@ -9,8 +9,8 @@ print.miivs <- function(x,...){
     z <- x$eqns
   
     for (i in 1:length(z)){
-      LHS <- paste(z[[i]]$DVobs, collapse = ", ")
-      RHS <- paste(z[[i]]$IVobs, collapse = ", ")
+      LHS <- paste(paste(z[[i]]$DVobs, collapse = ", "), " ")
+      RHS <- paste(paste(z[[i]]$IVobs, collapse = ", "), " ")
       Instruments <- paste(z[[i]]$MIIVs, collapse = ", ")
       Disturbance <- paste(z[[i]]$CDist, collapse = ", ", sep="")
       modtemp <- as.data.frame(cbind(LHS, RHS, Disturbance, Instruments))
